/*
 *  /MathJax-v2/localization/sk/MathMenu.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("sk","MathMenu",{version:"2.7.8",isLoaded:true,strings:{Show:"Zobrazi\u0165 matematiku ako",MathMLcode:"MathML k\u00F3d",OriginalMathML:"P\u00F4vodn\u00FD MathML",TeXCommands:"Pr\u00EDkazy TeXu",AsciiMathInput:"Vstup AsciiMathML",Original:"P\u00F4vodn\u00E1 forma",ErrorMessage:"Chybov\u00E9 hl\u00E1senie",Annotation:"Anot\u00E1cia",TeX:"TeX",StarMath:"StarMath",Maple:"Javor",ContentMathML:"Obsah MathML",OpenMath:"OpenMath",texHints:"Zobrazi\u0165 TeX tipy v MathML",Settings:"Nastavenia matematiky",ZoomTrigger:"Aktiv\u00E1cia zoomu",Hover:"Prejdenie my\u0161ou",Click:"Kliknutie",DoubleClick:"Dvojit\u00E9 kliknutie",NoZoom:"Bez zoomu",TriggerRequires:"Aktiv\u00E1cia vy\u017Eaduje:",Option:"Mo\u017Enos\u0165",Alt:"Alt",Command:"Command",Control:"Ctrl",Shift:"Shift",ZoomFactor:"Miera zoomu",Renderer:"Vykres\u013Eovanie matematiky",MPHandles:"Necha\u0165 MathPlayer spracov\u00E1va\u0165:",MenuEvents:"Udalosti menu",MouseEvents:"Udalosti my\u0161i",MenuAndMouse:"Udalosti my\u0161i a menu",FontPrefs:"Preferencia typu p\u00EDsma",ForHTMLCSS:"Pre HTML-CSS",Auto:"Automaticky",TeXLocal:"TeX (lok\u00E1lny)",TeXWeb:"TeX (webov\u00FD)",TeXImage:"TeX (obr\u00E1zkov\u00FD)",STIXLocal:"STIX (lok\u00E1lny)",STIXWeb:"STIX (webov\u00FD)",AsanaMathWeb:"Asana Math (webov\u00FD)",GyrePagellaWeb:"Gyre Pagella (web)",GyreTermesWeb:"Gyre Termes (web)",LatinModernWeb:"Latin Modern (web)",NeoEulerWeb:"Neo Euler (web)",ContextMenu:"Kontextov\u00E9 menu",Browser:"Prehliada\u010D",Scale:"\u0160k\u00E1lova\u0165 v\u0161etku matematiku",Discoverable:"Zv\u00FDraznit p\u0159i prejden\u00ED my\u0161ou",Locale:"Jazyk",LoadLocale:"Na\u010D\u00EDta\u0165 z URL\u2026",About:"O MathJaxe",Help:"N\u00E1poveda k MathJaxu",localTeXfonts:"pou\u017E\u00EDvaj\u00FA se lok\u00E1lne p\u00EDsma TeXu",webTeXfonts:"pou\u017E\u00EDvaj\u00FA se webov\u00E9 p\u00EDsma TeXu",imagefonts:"pou\u017E\u00EDvaj\u00FA sa obr\u00E1zkov\u00E9 p\u00EDsma",localSTIXfonts:"pou\u017E\u00EDvaj\u00FA se lok\u00E1lne p\u00EDsma STIX",webSVGfonts:"pou\u017E\u00EDvaj\u00ED se webov\u00E9 SVG p\u00EDsma",genericfonts:"pou\u017E\u00EDvaj\u00ED se generick\u00E1 p\u00EDsma sady Unicode",wofforotffonts:"p\u00EDsma WOFF alebo OTF",eotffonts:"p\u00EDsma EOT",svgfonts:"p\u00EDsma SVG",WebkitNativeMMLWarning:"V\u00E1\u0161 prehliada\u010D zjavne nepodporuje MathML, tak\u017Ee prepnutie na MathML v\u00FDstup m\u00F4\u017Ee zp\u00F4sobi\u0165, \u017Ee bude matematika na tejto str\u00E1nke ne\u010Ditate\u013En\u00E1.",MSIENativeMMLWarning:"Internet Explorer vy\u017Eaduje plugin MathPlayer na spracovanie v\u00FDstupu MathML",OperaNativeMMLWarning:"Podpora prehliada\u010Da Opera pre MathML je obmedzen\u00E1, \u010Di\u017Ee prechod k v\u00FDstupu MathML m\u00F4\u017Ee sp\u00F4sobi\u0165 chab\u00E9 vykres\u013Eovanie niektor\u00FDch v\u00FDrazov",SafariNativeMMLWarning:"Vstavan\u00E1 podpora v\u00E1\u0161ho prehliada\u010Da pre MathML neimplementuje v\u0161etky vymo\u017Eenosti pou\u017E\u00EDvan\u00E9 MathJax-om, \u010Do m\u00F4\u017Ee sp\u00F4sobi\u0165 chab\u00E9 vykres\u013Eovanie ist\u00FDch v\u00FDrazov",FirefoxNativeMMLWarning:"Vstavan\u00E1 podpora MathML v\u00E1\u0161ho prehliada\u010Da neimplementuje v\u0161etky vymo\u017Eenosti pou\u017E\u00EDvan\u00E9 MathJaxom, \u010Do znamen\u00E1, \u017Ee niektor\u00E9 v\u00FDrazy sa nebud\u00FA vykres\u013Eova\u0165 spr\u00E1vne.",MSIESVGWarning:"SVG nie je implementovan\u00E9 v prehliada\u010Doch Internet Explorer pred verziou IE9 a v emul\u00E1ciach verzi\u00ED IE8 \u010Di ni\u017E\u0161\u00EDch. Prepnutie na v\u00FDstup SVG sp\u00F4sob\u00ED, \u017Ee sa matematika nebude zobrazova\u0165 spr\u00E1vne.",LoadURL:"Na\u010D\u00EDta\u0165 d\u00E1ta prekladu z tejto adresy URL:",BadURL:"Adresa URL mus\u00ED by\u0165 adresou s\u00FAboru p\u00EDsan\u00E9ho v JavaScripte, ktor\u00FD definuje d\u00E1ta prekladu pre MathJax. S\u00FAbory JavaScriptu maj\u00FA zvy\u010Dajne predponu '.js'.",BadData:"Nepodarilo sa na\u010D\u00EDta\u0165 d\u00E1ta prekladu z %1",SwitchAnyway:"Prajete si aj napriek tomu prepn\u00FA\u0165 vykres\u013Eovanie?\n\n(Stla\u010Dte OK pre prepnutie, ZRU\u0160I\u0164 pre zru\u0161enie s aktu\u00E1lnym vykres\u013Eovan\u00EDm)",ScaleMath:"Na\u0161k\u00E1lova\u0165 v\u0161etku matematiku (v porovnan\u00ED s okolit\u00FDm textom) o",NonZeroScale:"\u0160k\u00E1la nesmie by\u0165 nulov\u00E1",PercentScale:"\u0160k\u00E1la mus\u00ED by\u0165 percentom (napr\u00EDklad 120%%)",IE8warning:"T\u00FDmto deaktivujete menu MathJaxu a mo\u017Enosti zoomu, no pou\u017Eit\u00EDm kombin\u00E1cie Alt+Click na v\u00FDraz z\u00EDskate menu MathJaxu\n\nNaozaj si prajete zmeni\u0165 nastavenia MathPlayer-u?",IE9warning:"Kontextov\u00E9 menu MathJaxu bude vypnut\u00E9, no pou\u017Eite kombin\u00E1ciu Alt+Click na v\u00FDraz pre z\u00EDskanie nov\u00E9ho menu",NoOriginalForm:"P\u00F4vodn\u00E1 forma nie je dostupn\u00E1",Close:"Zatvori\u0165",EqSource:"Zdroj rovn\u00EDc pre MathJax",CloseAboutDialog:'Zatvori\u0165 okno "O MathJaxe"',FastPreview:"Rychl\u00FD n\u00E1h\u013Ead",AssistiveMML:"Pomocn\u00E9 MathML",InTabOrder:"Zaradit do postupnosti tabul\u00E1torov"}});MathJax.Ajax.loadComplete("[MathJax]/localization/sk/MathMenu.js");
